@@ -4,12 +4,8 @@ use warnings;
 use Cwd qw( cwd );
 use Data::Dumper;
 
-$Data::Dumper::Sortkeys++;
-
 my $input = $ENV{SYS_CMD_INPUT} ? join( '', <> ) : '';
 
-binmode STDOUT, ':encoding(utf8)';
-
 print Data::Dumper->Dump(
     [
         {
